<?php
/*
Plugin Name: Concerts
Plugin URI: http://www.atypisch.nl
Description: This plugin enables the user to show a list of concerts 
Author:  Marten Timan
Version: 0.0.1
Author URI: http://www.atypisch.nl

#===== File information
Revisiondate: 30-08-2006
File version: 01
*/

#---------------------------------------------------
# Install MySQL Tables
#---------------------------------------------------
if ( !concerts_mysql_table_exists($wpdb, $table_prefix."concerts") ) concerts_mysql_install($wpdb, $table_prefix);

#---------------------------------------------------
# Only proceed with the plugin if MySQL Tables are setup properly
#---------------------------------------------------
if ( concerts_mysql_table_exists($wpdb, $table_prefix."concerts") ) {

	concerts_check_config(); //Initialize Configuration Variables

	add_action('admin_menu', 'concerts_add_pages'); //Add page menu links

	if ( isset($_POST['concerts_submit']) AND $_GET['new'] == "true")
		add_action('init', 'concerts_insert_input'); //New concert
		
	if ( isset($_POST['update_submit'])  AND $_GET['update'] == "true")
		add_action('init', 'check_update_permission'); //check concert update permission	
		//add_action('init', 'concerts_update_concertid');
		
	if ( isset($_GET['delete_concert']) )
		add_action('init', 'concerts_request_delete'); //Delete concert

	if ( isset($_POST['concerts_submit_options']) AND $_GET['updated'] == "true")
		add_action('init', 'concerts_options_submit'); //Update Options

	if ( isset($_POST['concert_uninstall']) )
		add_action('init', 'concerts_plugin_uninstall'); //Uninstall

	// Load Options
	$concerts_config = get_option('concerts_config');
}

/*-------------------------------------------------------------
 Name:      concerts_mysql_install
 Purpose:   Creates database table if it doesnt exist
 Receive:   $wpdb, $table_prefix
 Return:	-none-
-------------------------------------------------------------*/
function concerts_mysql_install( $wpdb, $table_prefix ) {
	require_once(ABSPATH . 'wp-admin/upgrade-functions.php');

	$table_name = $table_prefix . "concerts";
	$sql = "CREATE TABLE ".$table_name." (
		id mediumint(8) unsigned NOT NULL auto_increment,
		venue varchar(255) NOT NULL default '',
		city varchar(255) NOT NULL default '',
		start varchar(10) NOT NULL default '',
		price varchar(20) NOT NULL default '',
		bands varchar(255) NOT NULL default '',
		description varchar(255) NOT NULL default '',
		moreinfo varchar(255) NOT NULL default '',
		thedate int(15) NOT NULL,
		author varchar(60) NOT NULL default '',
		active int(1) NOT NULL default '1',
		PRIMARY KEY (id)
		);";

	dbDelta($sql);

	if ( !concerts_mysql_table_exists( $wpdb, $table_name ) ) {
		add_action('admin_menu', 'concerts_mysql_warning');
	}
}

/*-------------------------------------------------------------
 Name:      concerts_mysql_table_exists
 Purpose:   Check if the table exists in the database
 Receive:   $wpdb, $table_name
 Return:	-none-
-------------------------------------------------------------*/
function concerts_mysql_table_exists( $wpdb, $table_name ) {
	if(!$wpdb->get_results("SHOW TABLES LIKE '%$table_name%'")) {
		return FALSE;
	} else {
		return TRUE;
	}
}

/*-------------------------------------------------------------
 Name:      concerts_mysql_warning
 Purpose:   Database errors if things go wrong
 Receive:   -none-
 Return:	-none-
-------------------------------------------------------------*/
function concerts_mysql_warning() {
	echo '<div class="updated"><h3>WARNING! The MySQL table was not created! You cannot store concerts.</h3></div>';
}


/*-------------------------------------------------------------
 Purpose:   Show concerts on a page template
 Receive:   -none-
 Return:	$output_page
-------------------------------------------------------------*/
function concerts_page() {
	global $wpdb, $table_prefix, $concerts_config;

	// Load Language file
	include 'lang_'.$concerts_config['language'].'.php';

	if($concerts_config['sortorder']=="thedate" or $concerts_config['sortorder']=="id"){
		/* Fetch concerts */
		$SQL = "SELECT id, venue, city, start, price, bands, description, moreinfo, thedate FROM ".$table_prefix."concerts WHERE active = 1 ORDER BY ".$concerts_config['sortorder']." asc";
		$concerts = $wpdb->get_results($SQL);
		/* Start processing data */
		
	
		

		if ( count($concerts) == 0 ) {
			$output_page .= '<i>'.$lang['noconcerts'].'</i>';
		} else {
			foreach ( $concerts as $concert ) {
			
				$moreinfo = $concert->moreinfo;
				$moreinfolink = "<a href=\"$moreinfo\">$moreinfo</a>";
			
				/* Build concert output */
				$output_page .= '<p>';
				$output_page .= '<b>';
				$output_page .= date($concerts_config['dateformat'], $concert->thedate);
				$output_page .= '</b>  ';
			
				$output_page .= $concert->venue;
				$output_page .= " ";
		
				$output_page .= $concert->city;
				$output_page .= " ";
			
				$output_page .= $concert->start;
				$output_page .= " ";
		
				$output_page .= $concert->price;
				$output_page .= " ";
			
				$output_page .= $concert->bands;
				$output_page .= " ";
			
				$output_page .= $concert->description;
				$output_page .= " ";
			
				$output_page .= $moreinfolink;
				$output_page .= "</p>";
				
			}
		}
	} else {
		/* Configuration is fuxored, output an error */
		$output_page .= '<li>'.$lang['config_error'].'.</li>';
	}
	$output_page .= '</ul>';
	return $output_page;
}

/*=======================
   ADMIN PANEL OPTIONS
 DO NOT EDIT BELOW HERE!
=======================*/

/*-------------------------------------------------------------
 Name:      concerts_insert_input
 Purpose:   Prepare input form on advanced edit post page
 Receive:   -None-
 Return:	-None-
-------------------------------------------------------------*/
function concerts_insert_input() {
	global $wpdb, $table_prefix, $userdata, $user_level, $concerts_config;

	if ( $user_level >= $concerts_config['minlevel'] ) {
		$concertmsg = 'Passed concert';
		$author = htmlentities(trim($_POST['username'], "\t\n "), ENT_QUOTES);
		$venue = htmlentities(trim($_POST['venue'], "\t\n "), ENT_QUOTES);
		$city = htmlentities(trim($_POST['city'], "\t\n "), ENT_QUOTES);
		$bands = htmlentities(trim($_POST['bands'], "\t\n "), ENT_QUOTES);
		$description = htmlentities(trim($_POST['description'], "\t\n "), ENT_QUOTES);
		$moreinfo = htmlentities(trim($_POST['moreinfo'], "\t\n "), ENT_QUOTES);
		$thedate = htmlentities(trim($_POST['thedate'], "\t\n "), ENT_QUOTES);
		$start = htmlentities(trim($_POST['start'], "\t\n "), ENT_QUOTES);
		$price = htmlentities(trim($_POST['price'], "\t\n "), ENT_QUOTES);
		$active = htmlentities(trim($_POST['active'], "\t\n "), ENT_QUOTES);

		if(strlen($author)!=0 AND strlen($description)<=255 AND strlen($thedate)!=0 AND strlen($thedate)<=10 AND strlen($start)<=10 ) {
			/* Date is sorted here */
			list($day, $month, $year) = split('[-]', $thedate);
			list($hour, $minute) = split('[:]', $start);
			$inputdate = mktime(0, 0, 0, $month, $day, $year);	
			
			/* Query */
			$postquery = "INSERT INTO
			".$table_prefix."concerts
			(venue, city, bands, description, moreinfo, start, price, thedate, author, active)
			VALUES
			('$venue', '$city', '$bands', '$description' ,'$moreinfo', '$start', '$price', '$inputdate', '$author' ,'$active')
			";
			if($wpdb->query($postquery)) {
				header('Location: edit.php?page=mt-concerts/mt-concerts.php&new_return=true');
			} else {
				die(mysql_error());
			}
		}
	}


}

/*-------------------------------------------------------------
////////////////////////////////////////////////////////////////DELETE/////
 Name:      concerts_request_delete
 Purpose:   Remove concert from database
 Receive:   concert id
 Return:    boolean
-------------------------------------------------------------*/
function concerts_request_delete() {
	global $userdata, $user_level, $table_prefix, $wpdb, $concerts_config;

	$concert_id = $_GET['delete_concert'];
	if($concert_id > 0) {
		$SQL = "SELECT
		".$table_prefix."concerts.id,
		".$table_prefix."concerts.author,
		".$table_prefix."users.display_name as display_name
		FROM
		".$table_prefix."concerts,
		".$table_prefix."users
		WHERE
		".$table_prefix."concerts.id = '$concert_id'
		AND
		".$table_prefix."users.display_name = ".$table_prefix."concerts.author";

		$concert = $wpdb->get_row($SQL);

		// Only allow delete if concert is lower user permissions or users own
		if ( $userdata->user_level >= $concerts_config['minlevel'] OR $concert->display_name  == $concert->author ) {
			if(concerts_delete_concertid($concert_id) == TRUE) {
				header('Location: edit.php?page=mt-concerts/mt-concerts.php&deleted_return=true');
			} else {
				die(mysql_error());
			}
		}
	}
}

/*-------------------------------------------------------------
 Name:      concerts_delete_concertid
 Purpose:   Remove concert from database
 Receive:   concert id
 Return:    boolean
-------------------------------------------------------------*/
function concerts_delete_concertid($concert_id) {
	if($concert_id > 0) {
		global $wpdb, $table_prefix;

		$SQL = "DELETE FROM ".$table_prefix."concerts WHERE id = $concert_id";
		if(!$wpdb->query($SQL)) {
			die(mysql_error());
		} else {
			return TRUE;
		}
	}
}

/*-------------------------------------------------------------
////////////////////////////////////////////////////////////////UPDATE/////
 Name:      concerts_request_update
 Purpose:   Remove concert from database
 Receive:   concert id
 Return:    boolean
-------------------------------------------------------------*/
function concerts_request_update() {
	global $userdata, $user_level, $table_prefix, $wpdb, $concerts_config;

	$concert_id = $_GET['update_concert'];
	
	if($concert_id > 0) {
		$SQL = "SELECT
		".$table_prefix."concerts.id,
		".$table_prefix."concerts.author,
		".$table_prefix."concerts.thedate,
		".$table_prefix."concerts.start,
		".$table_prefix."concerts.price,
		".$table_prefix."concerts.venue,
		".$table_prefix."concerts.city,
		".$table_prefix."concerts.bands,
		".$table_prefix."concerts.description,
		".$table_prefix."concerts.moreinfo,
		".$table_prefix."users.display_name as display_name
		FROM
		".$table_prefix."concerts,
		".$table_prefix."users
		WHERE
		".$table_prefix."concerts.id = '$concert_id'
		AND
		".$table_prefix."users.display_name = ".$table_prefix."concerts.author";

		$concert = $wpdb->get_row($SQL);
		return $concert;
	}
}

/*-------------------------------------------------------------
 Name:     check_update_permission
 Purpose:   update concert from database
 Receive:   concert id
 Return:    boolean
-------------------------------------------------------------*/

function check_update_permission($concert_id) {

			// Only allow update if concert is lower user permissions or users own
			if ( $userdata->user_level >= $concerts_config['minlevel'] OR $concert->display_name  == $concert->author ) {
				if(concerts_update_concertid($concert_id) == TRUE) {
					header('Location: edit.php?page=mt-concerts/mt-concerts.php&updated_return=true');
				} else {
					die(mysql_error());
				}
			}
}

/*-------------------------------------------------------------
 Name:      concerts_update_concertid
 Purpose:   Remove concert from database
 Receive:   concert id
 Return:    boolean
-------------------------------------------------------------*/
function concerts_update_concertid() {
	
	$concert_id = $_GET['update_concert'];
	if($concert_id > 0) {
	
	global $wpdb, $table_prefix, $userdata, $user_level, $concerts_config;
	
	if ( $user_level >= $concerts_config['minlevel'] ) {
		$concertmsg = 'Passed concert';
		
		$author = htmlentities(trim($_POST['username'], "\t\n "), ENT_QUOTES);
		$venue = htmlentities(trim($_POST['venue'], "\t\n "), ENT_QUOTES);
		$city = htmlentities(trim($_POST['city'], "\t\n "), ENT_QUOTES);
		$bands = htmlentities(trim($_POST['bands'], "\t\n "), ENT_QUOTES);
		$description = htmlentities(trim($_POST['description'], "\t\n "), ENT_QUOTES);
		$moreinfo = htmlentities(trim($_POST['moreinfo'], "\t\n "), ENT_QUOTES);
		$thedate = htmlentities(trim($_POST['thedate'], "\t\n "), ENT_QUOTES);
		$start = htmlentities(trim($_POST['start'], "\t\n "), ENT_QUOTES);
		$price = htmlentities(trim($_POST['price'], "\t\n "), ENT_QUOTES);
		$active = htmlentities(trim($_POST['active'], "\t\n "), ENT_QUOTES);

		if(strlen($author)!=0 AND strlen($description)<=255 AND strlen($thedate)!=0 AND strlen($thedate)<=10 AND strlen($start)<=10 ) {
			/* Date is sorted here */
			list($day, $month, $year) = split('[-]', $thedate);
			list($hour, $minute) = split('[:]', $start);
			$inputdate = mktime(0, 0, 0, $month, $day, $year);	
			
			/* Query */
			$updatequery = "UPDATE ".$table_prefix."concerts SET venue = '$venue', city = '$city', bands = '$bands', description = '$description', moreinfo = '$moreinfo', start = '$start', price = '$price', thedate = '$inputdate', author = '$author', active = '$active' WHERE id= '$concert_id' ";
			if($wpdb->query($updatequery)) {
				header('Location: edit.php?page=mt-concerts/mt-concerts.php&geupdated_return=true');
			} else {
				die(mysql_error());
			}
		}
	  }
     }

}



/*-------------------------------------------------------------
 Name:      concerts_add_pages
 Purpose:   Add pages to admin menus
 Receive:   -none-
 Return:    -none-
-------------------------------------------------------------*/
function concerts_add_pages() {
	global $concerts_config;

	add_management_page('Concerts', 'Concerts', $concerts_config['minlevel'], __FILE__, 'concerts_manage_page');
	add_options_page('Concerts', 'Concerts', 10, __FILE__, 'concerts_options_page');
}


/*UPDATE active field */

function updateActive($active, $concert_id) {
	if($concert_id > 0) {
		global $wpdb, $table_prefix;
		
		$query = "UPDATE ".$table_prefix."concerts SET active='$active' WHERE id='$concert_id'";
		$q = mysql_query($query) or die ("db problems: " . mysql_error());
		//echo $query;
		return $q;
	}
}
						


/*-------------------------------------------------------------
 Name:      concerts_manage_page
 Purpose:   Admin management page
 Receive:   -none-
 Return:    -none-
-------------------------------------------------------------*/
function concerts_manage_page() {
	global $table_prefix, $wpdb, $userdata, $concerts_config;

	if ($_GET['new_return'] == "true") : ?>
		<div id="message" class="updated fade"><p><?php _e('concert <strong>added</strong>.') ?></p>
		</div>
	<?php endif; ?>
	<?php if ($_GET['deleted_return'] == "true") : ?>
		<div id="message" class="updated fade"><p><?php _e('concert <strong>deleted</strong>.') ?></p>
		</div>
	<?php endif; ?>
	<?php
	if ($_GET['updated_return'] == "true") : ?>
		<div id="message" class="updated fade"><p><?php _e('concert <strong>changed</strong>.') ?></p>
		</div>
	<?php endif; ?>
	<?php if ($_GET['updated_return'] == "false") : ?>
		<div id="message" class="updated fade"><p><?php _e('concert <strong>unchanged</strong>.') ?></p>
		</div>
	<?php endif; ?>

	<div class="wrap">
	
	<?php
	if ( isset($_GET['update_concert']) ) {
	
		include("update.php"); 
		} else {
		
		include("manage.php"); }	
	 ?>
	
		
	</div>
<?php
}

/*-------------------------------------------------------------
 Name:      concerts_update_page
 Purpose:   Admin management page
 Receive:   concert_id
 Return:    boolean
-------------------------------------------------------------*/
function concerts_update_page() {
	global $table_prefix, $wpdb, $userdata, $concerts_config;

	if ($_GET['geupdated_return'] == "true") : ?>
		<div id="message" class="updated fade"><p><?php _e('concert <strong>changed</strong>.') ?></p>
		</div>
	<?php endif; ?>
	<?php if ($_GET['geupdated_return'] == "false") : ?>
		<div id="message" class="updated fade"><p><?php _e('concert <strong>unchanged</strong>.') ?></p>
		</div>
	<?php endif; ?>

	<div class="wrap">
	
	<?php
		include("update.php"); 
	 ?>
	
		
	</div>
<?php
}

/*-------------------------------------------------------------
 Name:      concerts_options_page
 Purpose:   Admin options page
 Receive:   -none-
 Return:    -none-
-------------------------------------------------------------*/
function concerts_options_page() {
	$concerts_config = get_option('concerts_config');
	global $user_level;

	if(!isset($_GET['error']) && $user_level >= 10) {
		?>
		<div class="wrap">
		  	<h2>concerts options</h2>
		  	<form method="post" action="<?=$_SERVER['REQUEST_URI']?>&amp;updated=true">
		    	<input type="hidden" name="concerts_submit_options" value="true" />
		    	<table width="100%" cellspacing="2" cellpadding="5" class="editform">
		      	<tr>
			        <th width="33%" scope="row">How much concerts to show in the sidebar:</th>
			        <td><input name="concerts_amount" type="text" value="<?=$concerts_config['amount'];?>" size="3" /> (default: 2)</td>
		      	</tr>
		      	<tr>
			        <th width="33%" scope="row">Dateformat:</th>
			        <td><input name="concerts_dateformat" type="text" value="<?=$concerts_config['dateformat'];?>" size="10" /> (default: <b>l, F jS</b> More <a href="http://codex.wordpress.org/Formatting_Date_and_Time" target="_blank" title="New window">info</a>.)</td>
		      	</tr>
		      	<tr>
			        <th width="33%" scope="row">Sortorder:</th>
			        <td><select name="concerts_sortorder">';
					<?php if($concerts_config['concerts_sortorder'] == "thedate") { ?>
				        <option value="thedate">Date</option>
						<option value="id">ID</option>
					<?php } else { ?>
						<option value="id">ID</option>
				        <option value="thedate">Date</option>
					<?php } ?>
					</select></td>
		      	</tr>
		      	<tr>
			        <th width="33%" scope="row">Language:</th>
			        <td><input name="concerts_language" type="text" value="<?=$concerts_config['language'];?>" size="10" /> (default: english)</td>
		      	</tr>
		      	<tr>
			        <th width="33%" scope="row">Minimum User Level for scheduling concerts:</th>
			        <td><input name="concerts_minlevel" type="text" value="<?=$concerts_config['minlevel'];?>" size="3" /></td>
		      	</tr>
					<th>User levels:</th>
					<td>
						10 - Administrator / 
						7 - Editor (default, recommended) / 
						2 - Author / 
						1 - Contributor / 
						0 - Subscriber
					</td>
		      	</tr>
		    	</table>
			    <p class="submit">
			      	<input type="submit" name="Submit" value="Update Options &raquo;" />
			    </p>
			</form>

		  	<h2>concerts Uninstall</h2>
		  	<p>concerts installs a table in MySQL. When you disable the plugin the table will not be deleted. To delete the table use the button below.</p>
		  	<p><b>WARNING!</b> -- This process is irreversible and will delete ALL scheduled concerts!</p>
		  	<p>No other parts of your wordpress installation will be touched.</p>
		  	<form method="post" action="<?=$_SERVER['REQUEST_URI']?>">
		  		<p class="submit">
		    	<input type="hidden" name="concert_uninstall" value="true" />
		    	<input onclick="return confirm('You are about to uninstall the concerts plugin\n  All scheduled concerts will be lost!\n\'OK\' to continue, \'Cancel\' to stop.')" type="submit" name="Submit" value="Uninstall Plugin &raquo;" />
		  		</p>
		  	</form>

		</div>
		<?php
	} // End If
}

/*-------------------------------------------------------------
 Name:      concerts_check_config
 Purpose:   Create or update the options
 Receive:   -none-
 Return:    -none-
-------------------------------------------------------------*/
function concerts_check_config() {
	if ( !$option = get_option('concerts_config') ) {
		// Default Options
		$option['amount'] = 2;
		$option['minlevel'] = 7;
		$option['dateformat'] = 'l, F jS H:i';
		$option['sortorder'] = 'thedate';
		$option['language'] = 'english';
		update_option('concerts_config', $option);
	}

	// If value not assigned insert default (upgrades)
	if (strlen($option['amount']) < 1 or strlen($option['minlevel']) < 1 or strlen($option['dateformat']) < 1 or strlen($option['sortorder']) < 1 or strlen($option['language']) < 1 ) {
		$option['amount'] = 2;
		$option['minlevel'] = 7;
		$option['dateformat'] = 'l, F jS H:i';
		$option['sortorder'] = 'thedate';
		$option['language'] = 'english';
		update_option('concerts_config', $option);
	}
}

/*-------------------------------------------------------------
 Name:      concerts_options_submit
 Purpose:   Save options
 Receive:   -none-
 Return:    -none-
-------------------------------------------------------------*/
function concerts_options_submit() {
	global $user_level;

	if ( $user_level >= 10 ) {
		//options page
		$option['amount'] = trim($_POST['concerts_amount'], "\t\n ");
		$option['minlevel'] = trim($_POST['concerts_minlevel'], "\t\n ");
		$option['dateformat'] = trim($_POST['concerts_dateformat'], "\t\n ");
		$option['sortorder'] = trim(strtolower($_POST['concerts_sortorder']), "\t\n ");
		$option['language'] = trim(strtolower($_POST['concerts_language']), "\t\n ");
		update_option('concerts_config', $option);
	}
}

/*-------------------------------------------------------------
 Name:      concerts_plugin_uninstall

 Purpose:   Delete the entire database table and remove the options on uninstall.
 Receive:   -none-
 Return:	-none-
-------------------------------------------------------------*/
function concerts_plugin_uninstall() {

	global $table_prefix, $zc_scriptname, $user_level;

	if ( $user_level >= 10 ) {
		// Drop MySQL Tables
		$SQL = "DROP TABLE ".$table_prefix."concerts";
		mysql_query($SQL) or die("An unexpected error occured. / ".mysql_error());

		// Delete Option
		delete_option('concerts_config');

		// Deactivate Plugin
		$current = get_settings('active_plugins');
        array_splice($current, array_search( "$zc_scriptname", $current), 1 );
		update_option('active_plugins', $current);

		$redirect_url = wp_nonce_url("plugins.php?action=deactivate&amp;plugin=mt-concerts/mt-concerts.php", 'deactivate-plugin_mt-concerts/mt-concerts.php');
		header('Location: '.$redirect_url);

		die();

	}
}
?>